********************
zenopy Documentation
********************

Welcome to ``zenopy's`` documentation.

``zenopy`` is an open-source python library that exposes the all functionalities
of the `Zenodo <https://zenodo.org>`_ API to researchers and software developers.

This package is a part of the data engineering domain infrastructure in the Chem-AI
software ecosystem.

.. toctree::
    :maxdepth: 4
    :titlesonly:
    :numbered: 4

    installation
    quick_start
    howtos/index
    tutorials/index
    manual/index
    api/index
    references
    dev_team
    acknowledgements